@@ -26,6 +26,7 @@ Example::
     ssh.cmd("ls -al")
     [...]
 """
+from __future__ import unicode_literals
 
 import io
 import os
@@ -121,7 +122,7 @@ class ConnectionBase(object):
         """ a wrapper for :pexpect:meth:`spawn.expect`
         """
         self.log("expect({},{},{})".format(
-            str(pattern).encode('string-escape'),
+            str(pattern).encode('unicode-escape'),
             timeout,
             searchwindowsize,
         ))
@@ -196,16 +197,17 @@ class ConnectionBase(object):
         self._sendline(prepped_msg)
         try:
             self._expect(expect or self.prompt, timeout=timeout or self.default_timeout)
-            self._logger.debug("SUCCESS: cmd({}) result='{}' expect-match='{}'".format(
-                str(msg)[:15].encode("string_escape") + ("[...]" if len(str(msg)) > 15 else ""),
-                str(self.exp.before)[:50].encode("string-escape") + ("[...]" if len(str(self.exp.before)) > 50 else ""),
-                str(self.exp.after)[:50].encode("string-escape") + ("[...]" if len(str(self.exp.after)) > 50 else ""),
-            ))
         except (pexpect.EOF, pexpect.TIMEOUT) as e:
             self.log("caught EOF/TIMEOUT on last expect; closing connections")
             self.close()
             raise e
-        return self._prep_cmdoutput(self.exp.before, prepped_msg, do_retcode)
+        out = self._prep_cmdoutput(self.exp.before, prepped_msg, do_retcode)
+        self._logger.debug("SUCCESS: cmd({}) result='{}' expect-match='{}'".format(
+            str(msg)[:15].encode("unicode_escape") + ("[...]" if len(str(msg)) > 15 else ""),
+            str(out[1])[:50].encode("unicode-escape") + ("[...]" if len(str(self.exp.before)) > 50 else ""),
+            str(self.exp.after)[:50].encode("unicode-escape") + ("[...]" if len(str(self.exp.after)) > 50 else ""),
+        ))
+        return out
 
     def _prep_cmdmessage(self, msg, do_retcode=True):
         """ prepares a command message before it is delivered to pexpect
@@ -213,7 +215,7 @@ class ConnectionBase(object):
         It might add retreiving a returncode and strips unnecessary whitespace.
         """
         self.log("prep_msg({},{})".format(
-            str(msg).encode("string-escape"),
+            str(msg).encode("unicode-escape"),
             do_retcode,
         ))
         # If the connection is a shell, you might want a returncode.
@@ -224,7 +226,7 @@ class ConnectionBase(object):
         prepped = "\n".join(line.strip() for line in msg.split("\n") if line.strip())
         out = prepped+get_retcode
         self.log("prepped:'{}'".format(
-            out.encode("string-escape"),
+            out.encode("unicode-escape"),
         ))
         return out
 
@@ -235,7 +237,7 @@ class ConnectionBase(object):
         returncode if one is requested.
         """
         self.log("prep_out({},{})".format(
-            str(out).encode("string-escape"),
+            str(out).encode("unicode-escape"),
             do_retcode,
         ))
         if not out:
@@ -251,7 +253,7 @@ class ConnectionBase(object):
             try:
                 match = re.search("\n?<retcode>(\d+)</retcode>.*\n", prepped_out)
                 self.log("found retcode string '{}'".format(
-                    str(match.group(0)).encode("string-escape"),
+                    str(match.group(0)).encode("unicode-escape"),
                 ))
                 retcode = int(match.group(1))
                 prepped_out = prepped_out.replace(match.group(0), "")
@@ -261,7 +263,7 @@ class ConnectionBase(object):
                 self._logger.exception(e)
                 raise NoRetcodeException("failed to find retcode with '{}'. Formatted output:'{}'".format(
                             e.__class__.__name__,
-                            prepped_out.encode("string-escape"),
+                            prepped_out.encode("unicode-escape"),
                 ))
         else:
             self.log("prepped without retcode")
